@@ -151,3 +151,19 @@ split_char <- function(x, split = ",") {
     return(NULL)
   unlist(strsplit(x, split = split))
 }
+
+
+
+apply_grid_theme <- function() {
+  toastui::set_grid_theme(
+    cell.normal.background = "#FFF",
+    cell.normal.border = "#D8DEE9",
+    cell.normal.showVerticalBorder = TRUE,
+    cell.normal.showHorizontalBorder = TRUE,
+    cell.header.border = "#D8DEE9",
+    area.header.border = "#4C566A",
+    cell.summary.border = "#D8DEE9",
+    cell.summary.showVerticalBorder = TRUE,
+    cell.summary.showHorizontalBorder = TRUE
+  )
+}
